Module bls

Module bls 

BLS12-381 field operation hooks.

Constants

BLS12_381_MODULUS
The base field modulus for the 12_381 curve, in little endian.
NQR_BLS12_381
A non-quadratic residue for the 12_381 base field in big endian.

Functions

hook_bls12_381_inverse
Given a field element, in big endian, this function computes the inverse.
hook_bls12_381_sqrt
Given a field element, in big endian, this function computes the square root.