pub enum ByteOpcode {
AND = 0,
OR = 1,
XOR = 2,
U8Range = 3,
LTU = 4,
MSB = 5,
Range = 6,
}Expand description
Byte Opcode.
This represents a basic operation that can be performed on a byte. Usually, these operations are performed via lookup tables on that iterate over the domain of two 8-bit values. The operations include both bitwise operations (AND, OR, XOR) as well as basic arithmetic.
Variants
AND = 0
Bitwise AND.
OR = 1
Bitwise OR.
XOR = 2
Bitwise XOR.
U8Range = 3
Unsigned 8-bit Range Check.
LTU = 4
Unsigned Less Than.
MSB = 5
Most Significant Bit.
Range = 6
Range Check.
Implementations
Sourceimpl ByteOpcode
impl ByteOpcode