pub enum CoreAirId {
Show 65 variants
SyscallCore = 48,
SyscallCoreUser = 49,
DivRem = 52,
DivRemUser = 53,
Add = 54,
AddUser = 55,
Addi = 56,
AddiUser = 57,
Addw = 58,
AddwUser = 59,
Sub = 60,
SubUser = 61,
Subw = 62,
SubwUser = 63,
Bitwise = 64,
BitwiseUser = 65,
Mul = 66,
MulUser = 67,
ShiftRight = 68,
ShiftRightUser = 69,
ShiftLeft = 70,
ShiftLeftUser = 71,
Lt = 72,
LtUser = 73,
LoadByte = 74,
LoadByteUser = 75,
LoadHalf = 76,
LoadHalfUser = 77,
LoadWord = 78,
LoadWordUser = 79,
LoadX0 = 80,
LoadX0User = 81,
LoadDouble = 82,
LoadDoubleUser = 83,
StoreByte = 84,
StoreByteUser = 85,
StoreHalf = 86,
StoreHalfUser = 87,
StoreWord = 88,
StoreWordUser = 89,
StoreDouble = 90,
StoreDoubleUser = 91,
UType = 92,
UTypeUser = 93,
Branch = 94,
BranchUser = 95,
Jal = 96,
JalUser = 97,
Jalr = 98,
JalrUser = 99,
SyscallInstrs = 100,
SyscallInstrsUser = 101,
MemoryBump = 102,
StateBump = 103,
MemoryLocal = 106,
Global = 107,
AluX0 = 110,
AluX0User = 111,
Mprotect = 112,
InstructionDecode = 114,
InstructionFetch = 115,
PageProt = 116,
PageProtLocal = 117,
TrapExec = 120,
TrapMem = 121,
}Expand description
RV64IM AIR Identifiers.
These identifiers are for the various chips in the rv64im prover. We need them in the executor to compute the memory cost of the current shard of execution.
The CoreAirIds are the AIRs that are not part of precompile shards and not the program or
byte AIR.
Variants
SyscallCore = 48
The syscall core chip.
SyscallCoreUser = 49
The syscall core chip for user mode.
DivRem = 52
The div rem chip.
DivRemUser = 53
The div rem chip for user mode.
Add = 54
The add chip.
AddUser = 55
The add chip for user mode.
Addi = 56
The addi chip.
AddiUser = 57
The addi chip for user mode.
Addw = 58
The addw chip.
AddwUser = 59
The addw chip for user mode.
Sub = 60
The sub chip.
SubUser = 61
The sub chip for user mode.
Subw = 62
The subw chip.
SubwUser = 63
The subw chip for user mode.
Bitwise = 64
The bitwise chip.
BitwiseUser = 65
The bitwise chip for user mode.
Mul = 66
The mul chip.
MulUser = 67
The mul chip for user mode.
ShiftRight = 68
The shift right chip.
ShiftRightUser = 69
The shift right chip for user mode.
ShiftLeft = 70
The shift left chip.
ShiftLeftUser = 71
The shift left chip for user mode.
Lt = 72
The lt chip.
LtUser = 73
The lt chip for user mode.
LoadByte = 74
The load byte chip.
LoadByteUser = 75
The load byte chip for user mode.
LoadHalf = 76
The load half chip.
LoadHalfUser = 77
The load half chip for user mode.
LoadWord = 78
The load word chip.
LoadWordUser = 79
The load word chip for user mode.
LoadX0 = 80
The load x0 chip.
LoadX0User = 81
The load x0 chip for user mode.
LoadDouble = 82
The load double chip.
LoadDoubleUser = 83
The load double chip for user mode.
StoreByte = 84
The store byte chip.
StoreByteUser = 85
The store byte chip for user mode.
StoreHalf = 86
The store half chip.
StoreHalfUser = 87
The store half chip for user mode.
StoreWord = 88
The store word chip.
StoreWordUser = 89
The store word chip for user mode.
StoreDouble = 90
The store double chip.
StoreDoubleUser = 91
The store double chip for user mode.
UType = 92
The utype chip.
UTypeUser = 93
The utype chip for user mode.
Branch = 94
The branch chip.
BranchUser = 95
The branch chip for user mode.
Jal = 96
The jal chip.
JalUser = 97
The jal chip for user mode.
Jalr = 98
The jalr chip.
JalrUser = 99
The jalr chip for user mode.
SyscallInstrs = 100
The syscall instructions chip.
SyscallInstrsUser = 101
The syscall instructions chip for user mode.
MemoryBump = 102
The memory bump chip.
StateBump = 103
The state bump chip.
MemoryLocal = 106
The memory local chip.
Global = 107
The global chip.
AluX0 = 110
The ALU x0 chip (all ALU ops with rd = x0).
AluX0User = 111
The ALU x0 chip (all ALU ops with rd = x0) for user mode.
Mprotect = 112
The mprotect chip.
InstructionDecode = 114
The instruction decode chip.
InstructionFetch = 115
The instruction fetch chip.
PageProt = 116
The page prot chip.
PageProtLocal = 117
The page prot local chip.
TrapExec = 120
The trap exec chip.
TrapMem = 121
The trap memory chip.