pub enum ExecutionError {
Show 15 variants
InvalidMemoryAccess(Opcode, u64),
InvalidMemoryAccessUntrustedProgram(u64),
UnsupportedSyscall(u32),
Breakpoint(),
ExceededCycleLimit(u64),
InvalidSyscallUsage(u64),
Unimplemented(),
EndInUnconstrained(),
UnconstrainedCycleLimitExceeded(u64),
UnexpectedExitCode(u32),
InstructionNotFound(),
InvalidShardingState(),
UnhandledTrap(TrapError),
TooMuchMemory(),
Other(String),
}Expand description
Errors that the executor can throw.
Variants
InvalidMemoryAccess(Opcode, u64)
The execution failed with an invalid memory access.
InvalidMemoryAccessUntrustedProgram(u64)
The address for an untrusted program instruction is not aligned to 4 bytes.
UnsupportedSyscall(u32)
The execution failed with an unimplemented syscall.
Breakpoint()
The execution failed with a breakpoint.
ExceededCycleLimit(u64)
The execution failed with an exceeded cycle limit.
InvalidSyscallUsage(u64)
The execution failed because the syscall was called in unconstrained mode.
Unimplemented()
The execution failed with an unimplemented feature.
EndInUnconstrained()
The program ended in unconstrained mode.
UnconstrainedCycleLimitExceeded(u64)
The unconstrained cycle limit was exceeded.
UnexpectedExitCode(u32)
The program ended with an unexpected status code.
InstructionNotFound()
Page protect is off, and the instruction is not found.
InvalidShardingState()
The sharding state is invalid.
UnhandledTrap(TrapError)
Trap occurred without a valid handler.
TooMuchMemory()
SP1 program consumes too much memory.
Other(String)
A generic error.