#[non_exhaustive]pub enum RetainedEventsPreset {
Bls12381Field,
Bn254Field,
Sha256,
Poseidon2,
U256Ops,
Secp256k1,
}Expand description
Allowed presets for collections of events that may be retained instead of deferred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Bls12381Field
Retain events for BLS12-381 base field arithmetic operations.
Bn254Field
Retain events for BN254 base field arithmetic operations.
Sha256
Retain events for SHA-256 operations.
Poseidon2
Retain events for Poseidon2 operations.
U256Ops
Retain events for U256Ops operations.
Secp256k1
Retain events for Secp256k1 operations.
Implementations
Sourceimpl RetainedEventsPreset
impl RetainedEventsPreset
Sourcepub const fn syscall_codes(&self) -> &'static [SyscallCode]
pub const fn syscall_codes(&self) -> &'static [SyscallCode]
The codes of syscalls that generate events that are retained by this preset.