RiscvAirId

Enum RiscvAirId 

pub enum RiscvAirId {
Show 122 variants Program = 0, ShaExtend = 1, ShaExtendControl = 2, ShaExtendControlUser = 3, ShaCompress = 4, ShaCompressControl = 5, ShaCompressControlUser = 6, EdAddAssign = 7, EdAddAssignUser = 8, EdDecompress = 9, EdDecompressUser = 10, Secp256k1AddAssign = 11, Secp256k1AddAssignUser = 12, Secp256k1DoubleAssign = 13, Secp256k1DoubleAssignUser = 14, Secp256r1AddAssign = 15, Secp256r1AddAssignUser = 16, Secp256r1DoubleAssign = 17, Secp256r1DoubleAssignUser = 18, KeccakPermute = 19, KeccakPermuteControl = 20, KeccakPermuteControlUser = 21, Bn254AddAssign = 22, Bn254AddAssignUser = 23, Bn254DoubleAssign = 24, Bn254DoubleAssignUser = 25, Bls12381AddAssign = 26, Bls12381AddAssignUser = 27, Bls12381DoubleAssign = 28, Bls12381DoubleAssignUser = 29, Uint256MulMod = 30, Uint256MulModUser = 31, Uint256Ops = 32, Uint256OpsUser = 33, Bls12381FpOpAssign = 34, Bls12381FpOpAssignUser = 35, Bls12381Fp2AddSubAssign = 36, Bls12381Fp2AddSubAssignUser = 37, Bls12381Fp2MulAssign = 38, Bls12381Fp2MulAssignUser = 39, Bn254FpOpAssign = 40, Bn254FpOpAssignUser = 41, Bn254Fp2AddSubAssign = 42, Bn254Fp2AddSubAssignUser = 43, Bn254Fp2MulAssign = 44, Bn254Fp2MulAssignUser = 45, Poseidon2 = 46, Poseidon2User = 47, SyscallCore = 48, SyscallCoreUser = 49, SyscallPrecompile = 50, SyscallPrecompileUser = 51, DivRem = 52, DivRemUser = 53, Add = 54, AddUser = 55, Addi = 56, AddiUser = 57, Addw = 58, AddwUser = 59, Sub = 60, SubUser = 61, Subw = 62, SubwUser = 63, Bitwise = 64, BitwiseUser = 65, Mul = 66, MulUser = 67, ShiftRight = 68, ShiftRightUser = 69, ShiftLeft = 70, ShiftLeftUser = 71, Lt = 72, LtUser = 73, LoadByte = 74, LoadByteUser = 75, LoadHalf = 76, LoadHalfUser = 77, LoadWord = 78, LoadWordUser = 79, LoadX0 = 80, LoadX0User = 81, LoadDouble = 82, LoadDoubleUser = 83, StoreByte = 84, StoreByteUser = 85, StoreHalf = 86, StoreHalfUser = 87, StoreWord = 88, StoreWordUser = 89, StoreDouble = 90, StoreDoubleUser = 91, UType = 92, UTypeUser = 93, Branch = 94, BranchUser = 95, Jal = 96, JalUser = 97, Jalr = 98, JalrUser = 99, SyscallInstrs = 100, SyscallInstrsUser = 101, MemoryBump = 102, StateBump = 103, MemoryGlobalInit = 104, MemoryGlobalFinalize = 105, MemoryLocal = 106, Global = 107, Byte = 108, Range = 109, AluX0 = 110, AluX0User = 111, Mprotect = 112, SigReturn = 113, InstructionDecode = 114, InstructionFetch = 115, PageProt = 116, PageProtLocal = 117, PageProtGlobalInit = 118, PageProtGlobalFinalize = 119, TrapExec = 120, TrapMem = 121,
}
RV64IM AIR Identifiers.

These identifiers are for the various chips in the rv64im prover. We need them in the executor to compute the memory cost of the current shard of execution.

The CoreAirIds are the AIRs that are not part of precompile shards and not the program or byte AIR.

Variants



Program = 0

The program chip.



ShaExtend = 1

The SHA-256 extend chip.



ShaExtendControl = 2

The sha extend control chip.



ShaExtendControlUser = 3

The sha extend control chip for user mode.



ShaCompress = 4

The SHA-256 compress chip.



ShaCompressControl = 5

The sha compress control chip.



ShaCompressControlUser = 6

The sha compress control chip for user mode.



EdAddAssign = 7

The Edwards add assign chip.



EdAddAssignUser = 8

The Edwards add assign chip for user mode.



EdDecompress = 9

The Edwards decompress chip.



EdDecompressUser = 10

The Edwards decompress chip for user mode.



Secp256k1AddAssign = 11

The secp256k1 add assign chip.



Secp256k1AddAssignUser = 12

The secp256k1 add assign chip for user mode.



Secp256k1DoubleAssign = 13

The secp256k1 double assign chip.



Secp256k1DoubleAssignUser = 14

The secp256k1 double assign chip for user mode.



Secp256r1AddAssign = 15

The secp256r1 add assign chip.



Secp256r1AddAssignUser = 16

The secp256r1 add assign chip for user mode.



Secp256r1DoubleAssign = 17

The secp256r1 double assign chip.



Secp256r1DoubleAssignUser = 18

The secp256r1 double assign chip for user mode.



KeccakPermute = 19

The Keccak permute chip.



KeccakPermuteControl = 20

The keccak permute control chip.



KeccakPermuteControlUser = 21

The keccak permute control chip for user mode.



Bn254AddAssign = 22

The bn254 add assign chip.



Bn254AddAssignUser = 23

The bn254 add assign chip for user mode.



Bn254DoubleAssign = 24

The bn254 double assign chip.



Bn254DoubleAssignUser = 25

The bn254 double assign chip for user mode.



Bls12381AddAssign = 26

The bls12-381 add assign chip.



Bls12381AddAssignUser = 27

The bls12-381 add assign chip for user mode.



Bls12381DoubleAssign = 28

The bls12-381 double assign chip.



Bls12381DoubleAssignUser = 29

The bls12-381 double assign chip for user mode.



Uint256MulMod = 30

The uint256 mul mod chip.



Uint256MulModUser = 31

The uint256 mul mod chip for user mode.



Uint256Ops = 32

The uint256 ops chip.



Uint256OpsUser = 33

The uint256 ops chip for user mode.



Bls12381FpOpAssign = 34

The bls12-381 fp op assign chip.



Bls12381FpOpAssignUser = 35

The bls12-381 fp op assign chip for user mode.



Bls12381Fp2AddSubAssign = 36

The bls12-381 fp2 add sub assign chip.



Bls12381Fp2AddSubAssignUser = 37

The bls12-381 fp2 add sub assign chip for user mode.



Bls12381Fp2MulAssign = 38

The bls12-381 fp2 mul assign chip.



Bls12381Fp2MulAssignUser = 39

The bls12-381 fp2 mul assign chip for user mode.



Bn254FpOpAssign = 40

The bn254 fp op assign chip.



Bn254FpOpAssignUser = 41

The bn254 fp op assign chip for user mode.



Bn254Fp2AddSubAssign = 42

The bn254 fp2 add sub assign chip.



Bn254Fp2AddSubAssignUser = 43

The bn254 fp2 add sub assign chip for user mode.



Bn254Fp2MulAssign = 44

The bn254 fp2 mul assign chip.



Bn254Fp2MulAssignUser = 45

The bn254 fp2 mul assign chip for user mode.



Poseidon2 = 46

The poseidon2 chip.



Poseidon2User = 47

The poseidon2 chip for user mode.



SyscallCore = 48

The syscall core chip.



SyscallCoreUser = 49

The syscall core chip for user mode.



SyscallPrecompile = 50

The syscall precompile chip.



SyscallPrecompileUser = 51

The syscall precompile chip for user mode.



DivRem = 52

The div rem chip.



DivRemUser = 53

The div rem chip for user mode.



Add = 54

The add chip.



AddUser = 55

The add chip for user mode.



Addi = 56

The addi chip.



AddiUser = 57

The addi chip for user mode.



Addw = 58

The addw chip.



AddwUser = 59

The addw chip for user mode.



Sub = 60

The sub chip.



SubUser = 61

The sub chip for user mode.



Subw = 62

The subw chip.



SubwUser = 63

The subw chip for user mode.



Bitwise = 64

The bitwise chip.



BitwiseUser = 65

The bitwise chip for user mode.



Mul = 66

The mul chip.



MulUser = 67

The mul chip for user mode.



ShiftRight = 68

The shift right chip.



ShiftRightUser = 69

The shift right chip for user mode.



ShiftLeft = 70

The shift left chip.



ShiftLeftUser = 71

The shift left chip for user mode.



Lt = 72

The lt chip.



LtUser = 73

The lt chip for user mode.



LoadByte = 74

The load byte chip.



LoadByteUser = 75

The load byte chip for user mode.



LoadHalf = 76

The load half chip.



LoadHalfUser = 77

The load half chip for user mode.



LoadWord = 78

The load word chip.



LoadWordUser = 79

The load word chip for user mode.



LoadX0 = 80

The load x0 chip.



LoadX0User = 81

The load x0 chip for user mode.



LoadDouble = 82

The load double chip.



LoadDoubleUser = 83

The load double chip for user mode.



StoreByte = 84

The store byte chip.



StoreByteUser = 85

The store byte chip for user mode.



StoreHalf = 86

The store half chip.



StoreHalfUser = 87

The store half chip for user mode.



StoreWord = 88

The store word chip.



StoreWordUser = 89

The store word chip for user mode.



StoreDouble = 90

The store double chip.



StoreDoubleUser = 91

The store double chip for user mode.



UType = 92

The utype chip.



UTypeUser = 93

The utype chip for user mode.



Branch = 94

The branch chip.



BranchUser = 95

The branch chip for user mode.



Jal = 96

The jal chip.



JalUser = 97

The jal chip for user mode.



Jalr = 98

The jalr chip.



JalrUser = 99

The jalr chip for user mode.



SyscallInstrs = 100

The syscall instructions chip.



SyscallInstrsUser = 101

The syscall instructions chip for user mode.



MemoryBump = 102

The memory bump chip.



StateBump = 103

The state bump chip.



MemoryGlobalInit = 104

The memory global init chip.



MemoryGlobalFinalize = 105

The memory global finalize chip.



MemoryLocal = 106

The memory local chip.



Global = 107

The global chip.



Byte = 108

The byte chip.



Range = 109

The range chip.



AluX0 = 110

The ALU x0 chip (all ALU ops with rd = x0).



AluX0User = 111

The ALU x0 chip (all ALU ops with rd = x0) for user mode.



Mprotect = 112

The mprotect chip.



SigReturn = 113

The sigreturn chip.



InstructionDecode = 114

The instruction decode chip.



InstructionFetch = 115

The instruction fetch chip.



PageProt = 116

The page prot chip.



PageProtLocal = 117

The page prot local chip.



PageProtGlobalInit = 118

The page prot global init chip.



PageProtGlobalFinalize = 119

The page prot global finalize chip.



TrapExec = 120

The trap exec chip.



TrapMem = 121

The trap memory chip.

Implementations

Source

impl RiscvAirId

pub fn core() -> Vec<RiscvAirId>

Returns the AIRs that are not part of precompile shards and not the program or byte AIR.

pub fn is_core(self) -> bool

Whether the ID represents a core AIR.

pub fn is_memory(self) -> bool

Whether the ID represents a memory AIR.

pub fn is_precompile(self) -> bool

Whether the ID represents a precompile AIR.

pub fn rows_per_event(&self) -> usize

The number of rows in the AIR produced by each event.

pub fn control_air_id(self, page_protect_enabled: bool) -> Option<RiscvAirId>

Get the ID of the AIR used in the syscall control implementation.

pub fn as_str(&self) -> &'static str

Returns the string representation of the AIR.