Module events

Module events 

Type definitions for the events emitted by the [crate::Executor] during execution.

Structs

AluEvent
Alu Instruction Event.
BranchEvent
Branch Instruction Event.
ByteLookupEvent
Byte Lookup Event.
EdDecompressEvent
Edwards Decompress Event.
EdwardsPageProtRecords
Edwards Page Prot Records
EllipticCurveAddEvent
Elliptic Curve Add Event.
EllipticCurveDecompressEvent
Elliptic Curve Point Decompress Event.
EllipticCurveDoubleEvent
Elliptic Curve Double Event.
EllipticCurvePageProtRecords
Elliptic Curve Page Prot Records.
Fp2AddSubEvent
Emulated Degree 2 Field Addition/Subtraction Events.
Fp2MulEvent
Emulated Degree 2 Field Multiplication Events.
FpOpEvent
Emulated Field Operation Events.
FpPageProtRecords
Each fp op has one read slice and one write slice operation that require page prot checks.
GlobalInteractionEvent
Global Interaction Event.
InstructionDecodeEvent
Instruction Decode Event.
InstructionFetchEvent
Instruction Fetch Event.
JumpEvent
Jump Instruction Event.
KeccakPermuteEvent
Keccak-256 Permutation Event.
KeccakPermutePageProtRecords
Keccak-256 Permutation Page Prot Records.
MProtectEvent
Mprotect precompile event.
MemInstrEvent
Memory Instruction Event.
MemoryEntry
Memory entry.
MemoryInitializeFinalizeEvent
Memory Initialize/Finalize Event.
MemoryLocalEvent
Memory Local Event.
MemoryReadRecord
Memory Read Record.
MemoryRecord
Memory Record.
MemoryWriteRecord
Memory Write Record.
PageProtInitializeFinalizeEvent
Page prot Initialize/Finalize Event.
PageProtLocalEvent
Page Prot Local Event.
PageProtRecord
Page Prot Record.
Poseidon2PrecompileEvent
Poseidon2PrecompileEvent Event.
PrecompileEventIter
An iterator over the variants of PrecompileEvent
PrecompileEvents
A record of all the precompile events.
ShaCompressEvent
SHA-256 Compress Event.
ShaCompressPageProtAccess
SHA-256 Compress Page Prot Access.
ShaExtendEvent
SHA-256 Extend Event.
ShaExtendMemoryRecords
SHA-256 Extend Memory Records.
ShaExtendPageProtRecords
SHA-256 Extend Page Prot Records.
SigReturnEvent
SigReturnEvent Event.
SyscallEvent
Syscall Event.
TrapExecEvent
A TrapExec Event.
TrapMemInstrEvent
Trap Memory Instruction Event.
U256xU2048MulEvent
U256xU2048 Mul Event.
U256xU2048MulPageProtRecords
U256xU2048 Mul Page Prot Records.
UTypeEvent
UType Instruction Event.
Uint256MulEvent
Uint256 Mul Event.
Uint256MulPageProtRecords
Uint256 Mul Page Prot Records.
Uint256OpsEvent
Uint256 operations event.
Uint256OpsPageProtRecords
Uint256 Ops Page Prot Records.

Enums

FieldOperation
This is an arithmetic operation for emulating modular arithmetic.
MemoryAccessPosition
Memory Access Position.
MemoryRecordEnum
Memory Record Enum.
PrecompileEvent
Precompile event. There should be one variant for every precompile syscall.
Uint256Operation
Uint256 operation types.

Constants

NUM_BYTE_OPS
The number of different byte operations.
NUM_LOCAL_MEMORY_ENTRIES_PER_ROW_EXEC
The number of local memory entries per row of the memory local chip.
NUM_LOCAL_PAGE_PROT_ENTRIES_PER_ROW_EXEC
The number of page prot entries per row of the page prot local chip.
NUM_PAGE_PROT_ENTRIES_PER_ROW_EXEC
The number of page prot entries per row of the page prot local chip.

Traits

ByteRecord
A type that can record byte lookup events.
IntoMemoryRecord
Trait to convert something into a MemoryRecord.
PrecompileLocalMemory
Trait to retrieve all the local memory events from a vec of precompile events.

Functions

format_table_line
Returns a formatted row of a table of counts (e.g. opcode_counts).
generate_execution_report
Returns sorted and formatted rows of a table of counts (e.g. opcode_counts).
sorted_table_lines
Returns a tuple containing everything needed to to correctly display a table of counts (e.g. opcode_counts):