pub struct ByteLookupEvent {
pub opcode: ByteOpcode,
pub a: u16,
pub b: u8,
pub c: u8,
}Expand description
Byte Lookup Event.
This object encapsulates the information needed to prove a byte lookup operation. This includes the shard, opcode, operands, and other relevant information.
Fields
opcode: ByteOpcodeThe opcode.
a: u16The first operand.
b: u8The second operand.
c: u8The third operand.
Implementations