pub struct EdDecompressEvent {
pub clk: u64,
pub ptr: u64,
pub sign: bool,
pub y_bytes: [u8; 32],
pub decompressed_x_bytes: [u8; 32],
pub x_memory_records: [MemoryWriteRecord; 4],
pub y_memory_records: [MemoryReadRecord; 4],
pub local_mem_access: Vec<MemoryLocalEvent>,
pub page_prot_records: EdwardsPageProtRecords,
pub local_page_prot_access: Vec<PageProtLocalEvent>,
}Expand description
Edwards Decompress Event.
This event is emitted when an edwards decompression operation is performed.
Fields
clk: u64The clock cycle.
ptr: u64The pointer to the point.
sign: boolThe sign bit of the point.
y_bytes: [u8; 32]The comprssed y coordinate as a list of bytes.
decompressed_x_bytes: [u8; 32]The decompressed x coordinate as a list of bytes.
x_memory_records: [MemoryWriteRecord; 4]The memory records for the x coordinate.
y_memory_records: [MemoryReadRecord; 4]The memory records for the y coordinate.
local_mem_access: Vec<MemoryLocalEvent>The local memory access events.
page_prot_records: EdwardsPageProtRecordsThe page prot records.
local_page_prot_access: Vec<PageProtLocalEvent>The local page prot access records.