#[repr(C)]pub struct MemoryLocalEvent {
pub addr: u64,
pub initial_mem_access: MemoryRecord,
pub final_mem_access: MemoryRecord,
}Expand description
Memory Local Event.
This object encapsulates the information needed to prove a memory access operation within a shard. This includes the address, initial memory access, and final memory access within a shard.
Fields
addr: u64The address.
initial_mem_access: MemoryRecordThe initial memory access.
final_mem_access: MemoryRecordThe final memory access.