#[repr(C)]pub struct PageProtInitializeFinalizeEvent {
pub page_idx: u64,
pub page_prot: u8,
pub timestamp: u64,
}Expand description
Page prot Initialize/Finalize Event.
This object encapsulates the information needed to prove a page prot initialize or finalize operation. This includes the page index, page prot, and timestamp.
Fields
page_idx: u64The page index.
page_prot: u8The page prot.
timestamp: u64The timestamp.
Implementations
Sourceimpl PageProtInitializeFinalizeEvent
impl PageProtInitializeFinalizeEvent
Sourcepub const fn initialize(page_idx: u64, page_prot: u8) -> Self
pub const fn initialize(page_idx: u64, page_prot: u8) -> Self
Creates a new PageProtInitializeFinalizeEvent for an initialization.
Sourcepub const fn finalize_from_record(
page_idx: u64,
record: &PageProtRecord,
) -> Self
pub const fn finalize_from_record( page_idx: u64, record: &PageProtRecord, ) -> Self
Creates a new PageProtInitializeFinalizeEvent for a finalization.