#[repr(C)]pub struct PageProtLocalEvent {
pub page_idx: u64,
pub initial_page_prot_access: PageProtRecord,
pub final_page_prot_access: PageProtRecord,
}Expand description
Page Prot Local Event.
This object encapsulates the information needed to prove a page prot access operation within a shard. This includes the page, initial page access, and final page access within a shard.
Fields
page_idx: u64The page idx.
initial_page_prot_access: PageProtRecordThe initial page prot access.
final_page_prot_access: PageProtRecordThe final page prot access.