#[repr(C)]pub struct SyscallEvent {
pub pc: u64,
pub next_pc: u64,
pub clk: u64,
pub op_a_0: bool,
pub should_send: bool,
pub syscall_code: SyscallCode,
pub syscall_id: u32,
pub arg1: u64,
pub arg2: u64,
pub exit_code: u32,
}Expand description
Syscall Event.
This object encapsulated the information needed to prove a syscall invocation from the CPU table. This includes its shard, clk, syscall id, arguments, other relevant information.
Fields
pc: u64The program counter.
next_pc: u64The next program counter.
clk: u64The clock cycle.
op_a_0: boolWhether the first operand is register 0.
should_send: boolWhether this syscall should be sent.
syscall_code: SyscallCodeThe syscall code.
syscall_id: u32The syscall id.
arg1: u64The first operand value (op_b).
arg2: u64The second operand value (op_c).
exit_code: u32The exit code.