pub trait PrecompileLocalMemory {
// Required methods
fn get_local_mem_events(
&self,
) -> impl IntoIterator<Item = &MemoryLocalEvent>;
fn get_local_page_prot_events(
&self,
) -> impl IntoIterator<Item = &PageProtLocalEvent>;
}Expand description
Trait to retrieve all the local memory events from a vec of precompile events.
Required Methods
Sourcefn get_local_mem_events(&self) -> impl IntoIterator<Item = &MemoryLocalEvent>
fn get_local_mem_events(&self) -> impl IntoIterator<Item = &MemoryLocalEvent>
Get an iterator of all the local memory events.
Sourcefn get_local_page_prot_events(
&self,
) -> impl IntoIterator<Item = &PageProtLocalEvent>
fn get_local_page_prot_events( &self, ) -> impl IntoIterator<Item = &PageProtLocalEvent>
Get an iterator of all the local page prot events.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".