pub struct CoreVM<'a> {
pub mem_reads: MemReads<'a>,
pub program: Arc<Program>,
pub opts: SP1CoreOpts,
pub clk_end: u64,
pub public_value_digest: [u32; 8],
pub proof_nonce: [u32; 4],
/* private fields */
}Expand description
A RISC-V VM that uses a MinimalTrace to oracle memory access.
Fields
mem_reads: MemReads<'a>The memory reads cursoir.
program: Arc<Program>The program that is being executed.
opts: SP1CoreOptsThe options to configure the VM, mostly for syscall / shard handling.
clk_end: u64The end clk of the trace chunk.
public_value_digest: [u32; 8]The public value digest.
proof_nonce: [u32; 4]The nonce associated with the proof.
Implementations
Sourceimpl<'a> CoreVM<'a>
impl<'a> CoreVM<'a>
Sourcepub fn new<T: MinimalTrace>(
trace: &'a T,
program: Arc<Program>,
opts: SP1CoreOpts,
proof_nonce: [u32; 4],
) -> Self
pub fn new<T: MinimalTrace>( trace: &'a T, program: Arc<Program>, opts: SP1CoreOpts, proof_nonce: [u32; 4], ) -> Self
Create a CoreVM from a MinimalTrace and a Program.
Sourcepub fn fetch(&mut self) -> Option<&Instruction>
pub fn fetch(&mut self) -> Option<&Instruction>
Fetch the next instruction from the program.
Sourcepub fn advance(&mut self) -> CycleResult
pub fn advance(&mut self) -> CycleResult
Increment the state of the VM by one cycle. Calling this method will update the pc and the clk to the next cycle.
Sourcepub fn execute_load(
&mut self,
instruction: &Instruction,
) -> Result<LoadResult, ExecutionError>
pub fn execute_load( &mut self, instruction: &Instruction, ) -> Result<LoadResult, ExecutionError>
Execute a load instruction.
Sourcepub fn execute_store(
&mut self,
instruction: &Instruction,
) -> Result<StoreResult, ExecutionError>
pub fn execute_store( &mut self, instruction: &Instruction, ) -> Result<StoreResult, ExecutionError>
Execute a store instruction.
Sourcepub fn execute_alu(&mut self, instruction: &Instruction) -> AluResult
pub fn execute_alu(&mut self, instruction: &Instruction) -> AluResult
Execute an ALU instruction.
Sourcepub fn execute_jump(&mut self, instruction: &Instruction) -> JumpResult
pub fn execute_jump(&mut self, instruction: &Instruction) -> JumpResult
Execute a jump instruction.
Sourcepub fn execute_branch(&mut self, instruction: &Instruction) -> BranchResult
pub fn execute_branch(&mut self, instruction: &Instruction) -> BranchResult
Execute a branch instruction.
Sourcepub fn execute_utype(&mut self, instruction: &Instruction) -> UTypeResult
pub fn execute_utype(&mut self, instruction: &Instruction) -> UTypeResult
Execute a U-type instruction.
Sourcepub fn execute_ecall<RT>(
rt: &mut RT,
instruction: &Instruction,
code: SyscallCode,
) -> Result<EcallResult, ExecutionError>where
RT: SyscallRuntime<'a>,
pub fn execute_ecall<RT>(
rt: &mut RT,
instruction: &Instruction,
code: SyscallCode,
) -> Result<EcallResult, ExecutionError>where
RT: SyscallRuntime<'a>,
Execute an ecall instruction.
WARNING:
Its up to the syscall handler to update the shape checker abouut sent/internal ecalls.
Sourcepub fn read_code(&self) -> SyscallCode
pub fn read_code(&self) -> SyscallCode
Peek to get the code from the x5 register.
Sourceimpl CoreVM<'_>
impl CoreVM<'_>
Sourcepub fn register_refresh(&mut self) -> [MemoryReadRecord; 32]
pub fn register_refresh(&mut self) -> [MemoryReadRecord; 32]
Touch all the registers in the VM, bumping thier clock to self.clk - 1.
Sourceimpl CoreVM<'_>
impl CoreVM<'_>
Sourcepub const fn timestamp(&self, position: MemoryAccessPosition) -> u64
pub const fn timestamp(&self, position: MemoryAccessPosition) -> u64
Get the current timestamp for a given memory access position.
Sourcepub const fn needs_bump_clk_high(&self) -> bool
pub const fn needs_bump_clk_high(&self) -> bool
Check if the top 24 bits have changed, which imply a state bump event needs to be emitted.
Sourcepub const fn needs_state_bump(&self, instruction: &Instruction) -> bool
pub const fn needs_state_bump(&self, instruction: &Instruction) -> bool
Check if the state needs to be bumped, which implies a state bump event needs to be
emitted.
Sourceimpl<'a> CoreVM<'a>
impl<'a> CoreVM<'a>
Sourcepub const fn clk(&self) -> u64
pub const fn clk(&self) -> u64
Get the current clock, this clock is incremented by [CLK_INC] each cycle.
Sourcepub fn set_next_clk(&mut self, clk: u64)
pub fn set_next_clk(&mut self, clk: u64)
Set the next clock.
Sourcepub fn global_clk(&self) -> u64
pub fn global_clk(&self) -> u64
Get the global clock, this clock is incremented by 1 each cycle.
Sourcepub const fn next_pc(&self) -> u64
pub const fn next_pc(&self) -> u64
Get the next program counter that will be set in CoreVM::advance.
Sourcepub fn set_next_pc(&mut self, pc: u64)
pub fn set_next_pc(&mut self, pc: u64)
Set the next program counter.
Sourcepub fn set_exit_code(&mut self, exit_code: u32)
pub fn set_exit_code(&mut self, exit_code: u32)
Set the exit code.
Sourcepub fn set_global_clk(&mut self, global_clk: u64)
pub fn set_global_clk(&mut self, global_clk: u64)
Set the global clock.
Sourcepub const fn next_clk(&self) -> u64
pub const fn next_clk(&self) -> u64
Get the next clock that will be set in CoreVM::advance.
Sourcepub fn registers(&self) -> &[MemoryRecord; 32]
pub fn registers(&self) -> &[MemoryRecord; 32]
Get the current registers (immutable).
Sourcepub fn registers_mut(&mut self) -> &mut [MemoryRecord; 32]
pub fn registers_mut(&mut self) -> &mut [MemoryRecord; 32]
Get the current registers (mutable).
Sourcepub fn is_retained_syscall(&self, syscall_code: SyscallCode) -> bool
pub fn is_retained_syscall(&self, syscall_code: SyscallCode) -> bool
Check if the syscall is retained.
Sourcepub const fn is_trace_end(&self) -> bool
pub const fn is_trace_end(&self) -> bool
Check if the trace has ended.