pub struct ExecutionReport {
pub opcode_counts: Box<EnumMap<Opcode, u64>>,
pub syscall_counts: Box<EnumMap<SyscallCode, u64>>,
pub cycle_tracker: HashMap<String, u64>,
pub invocation_tracker: HashMap<String, u64>,
pub touched_memory_addresses: u64,
pub exit_code: u64,
/* private fields */
}Expand description
An execution report.
Fields
opcode_counts: Box<EnumMap<Opcode, u64>>The opcode counts.
syscall_counts: Box<EnumMap<SyscallCode, u64>>The syscall counts.
cycle_tracker: HashMap<String, u64>The cycle tracker counts.
invocation_tracker: HashMap<String, u64>Tracker for the number of cycle-tracker-report-* invocations for a specific label.
touched_memory_addresses: u64The unique memory address counts.
exit_code: u64The final exit code of the execution.
Implementations
Sourceimpl ExecutionReport
impl ExecutionReport
Sourcepub fn total_instruction_count(&self) -> u64
pub fn total_instruction_count(&self) -> u64
Compute the total number of instructions run during the execution.
Sourcepub fn total_syscall_count(&self) -> u64
pub fn total_syscall_count(&self) -> u64
Compute the total number of syscalls made during the execution.
Sourcepub fn total_record_size(&self) -> u64
pub fn total_record_size(&self) -> u64
The total size expected size (in bytes) of the execution report.