#[repr(C)]pub struct ExecutionState {Show 14 fields
pub pc: u64,
pub shard_finished: bool,
pub initial_timestamp: u64,
pub memory: Memory<MemoryEntry>,
pub page_prots: HashMap<u64, PageProtRecord>,
pub global_clk: u64,
pub clk: u64,
pub uninitialized_memory: Memory<u64>,
pub input_stream: VecDeque<Vec<u8>>,
pub proof_stream: Vec<(SP1RecursionProof<SP1GlobalContext, SP1PcsProofInner>, MachineVerifyingKey<SP1GlobalContext>)>,
pub proof_stream_ptr: usize,
pub public_values_stream: Vec<u8>,
pub public_values_stream_ptr: usize,
pub syscall_counts: HashMap<SyscallCode, u64>,
}Expand description
Holds data describing the current state of a program’s execution.
Fields
pc: u64The program counter.
shard_finished: boolWhether or not the shard is finished.
initial_timestamp: u64The starting timestamp of the current shard.
memory: Memory<MemoryEntry>The memory which instructions operate over. Values contain the memory value and last shard
- timestamp that each memory address was accessed.
page_prots: HashMap<u64, PageProtRecord>The page protection flags for each page in the memory. The default values should be
PROT_READ | PROT_WRITE.
global_clk: u64The global clock keeps track of how many instructions have been executed through all shards.
clk: u64The clock increments by 4 (possibly more in syscalls) for each instruction that has been executed in this shard.
uninitialized_memory: Memory<u64>Uninitialized memory addresses that have a specific value they should be initialized with.
SyscallHintRead uses this to write hint data into uninitialized memory.
input_stream: VecDeque<Vec<u8>>A stream of input values (global to the entire program).
proof_stream: Vec<(SP1RecursionProof<SP1GlobalContext, SP1PcsProofInner>, MachineVerifyingKey<SP1GlobalContext>)>A stream of proofs (reduce vk, proof, verifying key) inputted to the program.
proof_stream_ptr: usizeA ptr to the current position in the proof stream, incremented after verifying a proof.
public_values_stream: Vec<u8>A stream of public values from the program (global to entire program).
public_values_stream_ptr: usizeA ptr to the current position in the public values stream, incremented when reading from
public_values_stream.
syscall_counts: HashMap<SyscallCode, u64>Keeps track of how many times a certain syscall has been called.
Implementations
Sourceimpl ExecutionState
impl ExecutionState
Sourcepub fn new(pc_start: u64) -> Self
pub fn new(pc_start: u64) -> Self
Create a new ExecutionState.