pub struct GasEstimatingVM<'a> {
pub core: CoreVM<'a>,
pub gas_calculator: ReportGenerator,
pub hint_lens_idx: usize,
}Expand description
A RISC-V VM that uses a MinimalTrace to create a ExecutionReport.
Fields
core: CoreVM<'a>The core VM.
gas_calculator: ReportGeneratorThe gas calculator for the VM.
hint_lens_idx: usizeThe index of the hint lens the next shard will use.
Implementations
Sourceimpl GasEstimatingVM<'_>
impl GasEstimatingVM<'_>
Sourcepub fn execute(&mut self) -> Result<ExecutionReport, ExecutionError>
pub fn execute(&mut self) -> Result<ExecutionReport, ExecutionError>
Execute the program until it halts.
Sourcepub fn execute_instruction(&mut self) -> Result<CycleResult, ExecutionError>
pub fn execute_instruction(&mut self) -> Result<CycleResult, ExecutionError>
Execute the next instruction at the current PC.
Sourceimpl<'a> GasEstimatingVM<'a>
impl<'a> GasEstimatingVM<'a>
Sourcepub fn new<T: MinimalTrace>(
trace: &'a T,
program: Arc<Program>,
proof_nonce: [u32; 4],
opts: SP1CoreOpts,
) -> Self
pub fn new<T: MinimalTrace>( trace: &'a T, program: Arc<Program>, proof_nonce: [u32; 4], opts: SP1CoreOpts, ) -> Self
Create a new gas estimating VM from a minimal trace.
Sourcepub fn execute_load(
&mut self,
instruction: &Instruction,
) -> Result<(), ExecutionError>
pub fn execute_load( &mut self, instruction: &Instruction, ) -> Result<(), ExecutionError>
Execute a load instruction.
This method will update the local memory access for the memory read, the register read, and the register write.
It will also emit the memory instruction event and the events for the load instruction.
Sourcepub fn execute_store(
&mut self,
instruction: &Instruction,
) -> Result<(), ExecutionError>
pub fn execute_store( &mut self, instruction: &Instruction, ) -> Result<(), ExecutionError>
Execute a store instruction.
This method will update the local memory access for the memory read, the register read, and the register write.
It will also emit the memory instruction event and the events for the store instruction.
Sourcepub fn execute_alu(&mut self, instruction: &Instruction)
pub fn execute_alu(&mut self, instruction: &Instruction)
Execute an ALU instruction and emit the events.
Sourcepub fn execute_jump(&mut self, instruction: &Instruction)
pub fn execute_jump(&mut self, instruction: &Instruction)
Execute a jump instruction and emit the events.
Sourcepub fn execute_branch(&mut self, instruction: &Instruction)
pub fn execute_branch(&mut self, instruction: &Instruction)
Execute a branch instruction and emit the events.
Sourcepub fn execute_utype(&mut self, instruction: &Instruction)
pub fn execute_utype(&mut self, instruction: &Instruction)
Execute a U-type instruction and emit the events.
Sourcepub fn execute_ecall(
&mut self,
instruction: &Instruction,
) -> Result<(), ExecutionError>
pub fn execute_ecall( &mut self, instruction: &Instruction, ) -> Result<(), ExecutionError>
Execute an ecall instruction and emit the events.