#[repr(C)]pub struct Instruction {
pub opcode: Opcode,
pub op_a: u8,
pub op_b: u64,
pub op_c: u64,
pub imm_b: bool,
pub imm_c: bool,
}Expand description
RISC-V 64IM Instruction.
The structure of the instruction differs from the RISC-V ISA. We do not encode the instructions as 32-bit words, but instead use a custom encoding that is more friendly to decode in the SP1 zkVM.
Fields
opcode: OpcodeThe operation to execute.
op_a: u8The first operand.
op_b: u64The second operand.
op_c: u64The third operand.
imm_b: boolWhether the second operand is an immediate value.
imm_c: boolWhether the third operand is an immediate value.
Implementations
Sourceimpl Instruction
impl Instruction
Sourcepub const fn from_r_type(opcode: Opcode, dec_insn: &RType) -> Self
pub const fn from_r_type(opcode: Opcode, dec_insn: &RType) -> Self
Create a new Instruction from an R-type instruction.
Sourcepub const fn from_i_type(opcode: Opcode, dec_insn: &IType) -> Self
pub const fn from_i_type(opcode: Opcode, dec_insn: &IType) -> Self
Create a new Instruction from an I-type instruction.
Sourcepub const fn from_i_type_shamt(opcode: Opcode, dec_insn: &ITypeShamt) -> Self
pub const fn from_i_type_shamt(opcode: Opcode, dec_insn: &ITypeShamt) -> Self
Create a new Instruction from an I-type instruction with a shamt.
Sourcepub const fn from_i_type_shamt_w(opcode: Opcode, dec_insn: &ITypeShamtW) -> Self
pub const fn from_i_type_shamt_w(opcode: Opcode, dec_insn: &ITypeShamtW) -> Self
Create a new Instruction from an I-type instruction with a shamt_w.
Sourcepub const fn from_s_type(opcode: Opcode, dec_insn: &SType) -> Self
pub const fn from_s_type(opcode: Opcode, dec_insn: &SType) -> Self
Create a new Instruction from an S-type instruction.
Sourcepub const fn from_b_type(opcode: Opcode, dec_insn: &BType) -> Self
pub const fn from_b_type(opcode: Opcode, dec_insn: &BType) -> Self
Create a new Instruction from a B-type instruction.
Sourcepub const fn from_u_type(opcode: Opcode, dec_insn: &UType) -> Self
pub const fn from_u_type(opcode: Opcode, dec_insn: &UType) -> Self
Create a new Instruction from an U-type instruction.
Sourcepub const fn unimp() -> Self
pub const fn unimp() -> Self
Create a new Instruction that is not implemented.
Sourcepub const fn is_r_type(&self) -> bool
pub const fn is_r_type(&self) -> bool
Returns if the Instruction is an R-type instruction.
Sourcepub const fn is_i_type(&self) -> bool
pub const fn is_i_type(&self) -> bool
Returns whether the Instruction is an I-type instruction.
Sourcepub fn r_type(&self) -> (Register, Register, Register)
pub fn r_type(&self) -> (Register, Register, Register)
Decode the Instruction in the R-type format.
Sourcepub fn j_type(&self) -> (Register, u64)
pub fn j_type(&self) -> (Register, u64)
Decode the Instruction in the J-type format.
Sourcepub fn u_type(&self) -> (Register, u64)
pub fn u_type(&self) -> (Register, u64)
Decode the Instruction in the U-type format.
Sourceimpl Instruction
impl Instruction
Sourcepub const fn new(
opcode: Opcode,
op_a: u8,
op_b: u64,
op_c: u64,
imm_b: bool,
imm_c: bool,
) -> Self
pub const fn new( opcode: Opcode, op_a: u8, op_b: u64, op_c: u64, imm_b: bool, imm_c: bool, ) -> Self
Create a new [RiscvInstruction].
Sourcepub const fn is_alu_instruction(&self) -> bool
pub const fn is_alu_instruction(&self) -> bool
Returns if the instruction is an ALU instruction.
Sourcepub const fn is_ecall_instruction(&self) -> bool
pub const fn is_ecall_instruction(&self) -> bool
Returns if the instruction is a ecall instruction.
Sourcepub const fn is_memory_load_instruction(&self) -> bool
pub const fn is_memory_load_instruction(&self) -> bool
Returns if the instruction is a memory load instruction.
Sourcepub const fn is_memory_store_instruction(&self) -> bool
pub const fn is_memory_store_instruction(&self) -> bool
Returns if the instruction is a memory store instruction.
Sourcepub const fn is_branch_instruction(&self) -> bool
pub const fn is_branch_instruction(&self) -> bool
Returns if the instruction is a branch instruction.
Sourcepub const fn is_jump_instruction(&self) -> bool
pub const fn is_jump_instruction(&self) -> bool
Returns if the instruction is a jump instruction.
Sourcepub const fn is_jal_instruction(&self) -> bool
pub const fn is_jal_instruction(&self) -> bool
Returns if the instruction is a jal instruction.
Sourcepub const fn is_jalr_instruction(&self) -> bool
pub const fn is_jalr_instruction(&self) -> bool
Returns if the instruction is a jalr instruction.
Sourcepub const fn is_utype_instruction(&self) -> bool
pub const fn is_utype_instruction(&self) -> bool
Returns if the instruction is a utype instruction.
Sourcepub const fn is_with_correct_next_pc(&self) -> bool
pub const fn is_with_correct_next_pc(&self) -> bool
Returns if the instruction guarantees that the next_pc are with correct limbs.
Sourcepub const fn is_divrem_instruction(&self) -> bool
pub const fn is_divrem_instruction(&self) -> bool
Returns if the instruction is a divrem instruction.
Sourcepub const fn is_ebreak_instruction(&self) -> bool
pub const fn is_ebreak_instruction(&self) -> bool
Returns if the instruction is an ebreak instruction.
Sourcepub const fn is_unimp_instruction(&self) -> bool
pub const fn is_unimp_instruction(&self) -> bool
Returns if the instruction is an unimplemented instruction.