MinimalExecutor

Struct MinimalExecutor 

pub struct MinimalExecutor { /* private fields */ }
A minimal trace executor.

This executor runs SP1 program in current process. It lacks certain protections:

  • The used memory by SP1 program is not limited.
  • VM memory is one flat region of memory, there is no out-of-bound checks. As a result, it is only suitable for known programs. Please refer to sp1_core_executor_runner::MinimalExecutorRunner for running arbitrary SP1 programs.

Implementations

Source

impl MinimalExecutor

pub fn new( program: Arc<Program>, is_debug: bool, max_trace_size: Option<u64>, ) -> Self

Create a new minimal executor and transpile the program.

Arguments
  • program - The program to execute.
  • is_debug - Whether to compile the program with debugging.
  • max_trace_size - The maximum trace size in terms of MemValues. If not set tracing will be disabled.
pub fn simple(program: Arc<Program>) -> Self

Create a new minimal executor with no tracing or debugging.

pub fn tracing(program: Arc<Program>, max_trace_size: u64) -> Self

Create a new minimal executor with tracing.

Arguments
  • program - The program to execute.
  • max_trace_size - The maximum trace size in terms of MemValues. If not set, it will be set to 2 gb worth of memory events.
pub fn debug(program: Arc<Program>) -> Self

Create a new minimal executor with debugging.

pub fn with_input(&mut self, input: &[u8])

Add input to the executor.

pub fn execute_chunk(&mut self) -> Option<TraceChunkRaw>

Execute the program. Returning a trace chunk if the program has not completed.

pub fn run_till_end(&mut self) -> usize

Run MinimalExecutor till the end, returns the count of trace chunks generated. In normal use case, this method is defected and should not be used. In benchmarks, this method avoids overhead from creating anonymous zero-filled memory again and again. In a production setup, it’s likely MinimalExecutorRunner will use ring-buffer based shared memory trace buffer instead.

pub fn registers(&self) -> [u64; 32]

Get the registers of the JIT function.

pub fn pc(&self) -> u64

Get the program counter of the JIT function.

pub fn is_done(&self) -> bool

Check if the program has halted.

pub fn get_memory_value(&self, addr: u64) -> MemValue

Get the current value at an address.

pub fn program(&self) -> Arc<Program>

Get the program of the JIT function.

pub fn clk(&self) -> u64

Get the current clock of the JIT function.

This clock is incremented by 8 or 256 depending on the instruction.

pub fn global_clk(&self) -> u64

Get the global clock of the JIT function.

This clock is incremented by 1 per instruction.

pub fn exit_code(&self) -> u32

Get the exit code of the JIT function.

pub fn public_values_stream(&self) -> &Vec<u8>

Get the public values stream of the JIT function.

pub fn into_public_values_stream(self) -> Vec<u8>

Consume self, and return the public values stream.

pub fn hints(&self) -> &[(u64, Vec<u8>)]

Get the hints of the JIT function.

pub fn hint_lens(&self) -> Vec<usize>

Get the lengths of all the hints.

pub fn unsafe_memory(&self) -> UnsafeMemory

Get an unsafe memory view of the JIT function.

This allows reading without lifetime and mutability constraints.

pub fn reset(&mut self)

Reset the JIT function, to start from the beginning of the program.