Program

Struct Program 

pub struct Program {
    pub instructions: Vec<Instruction>,
    pub instructions_encoded: Option<Vec<u32>>,
    pub pc_start_abs: u64,
    pub pc_base: u64,
    pub page_prot_image: HashMap<u64, u8>,
    pub memory_image: Arc<HashMap<u64, u64>>,
    pub preprocessed_shape: Option<Shape<RiscvAirId>>,
    pub enable_untrusted_programs: bool,
    pub function_symbols: Vec<(String, u64, u64)>,
}
A program that can be executed by the SP1 zkVM.

Contains a series of instructions along with the initial memory image. It also contains the start address and base address of the program.

Fields

instructions: Vec<Instruction>

The instructions of the program.

instructions_encoded: Option<Vec<u32>>

The encoded instructions of the program. Only used if program is untrusted

pc_start_abs: u64

The start address of the program. It is absolute, meaning not relative to pc_base.

pc_base: u64

The base address of the program.

page_prot_image: HashMap<u64, u8>

The initial page protection image, mapping page indices to protection flags.

memory_image: Arc<HashMap<u64, u64>>

The initial memory image, useful for global constants

preprocessed_shape: Option<Shape<RiscvAirId>>

The shape for the preprocessed tables.

enable_untrusted_programs: bool

Flag indicating if untrusted programs are allowed.

function_symbols: Vec<(String, u64, u64)>

Function symbols for profiling & debugging. In the form of (name, start address, size)

Implementations

Source

impl Program

pub fn new( instructions: Vec<Instruction>, pc_start_abs: u64, pc_base: u64, ) -> Self

Create a new Program.

pub fn from(input: &[u8]) -> Result<Self>

Disassemble a RV64IM ELF to a program that be executed by the VM.

Errors

This function may return an error if the ELF is not valid.

pub fn from_elf(path: &str) -> Result<Self>

Disassemble a RV64IM ELF to a program that be executed by the VM from a file path.

Errors

This function will return an error if the file cannot be opened or read.

pub fn fixed_log2_rows<F: Field, A: MachineAir<F>>( &self, air: &A, ) -> Option<usize>

Custom logic for padding the trace to a power of two according to the proof shape.

pub fn fetch(&self, pc: u64) -> Option<&Instruction>

Fetch the instruction at the given program counter.