pub struct SP1ContextBuilder<'a> { /* private fields */ }Expand description
A builder for SP1Context.
Implementations
Sourceimpl<'a> SP1ContextBuilder<'a>
impl<'a> SP1ContextBuilder<'a>
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Create a new SP1ContextBuilder.
Prefer using SP1Context::builder.
Sourcepub fn build(&mut self) -> SP1Context<'a>
pub fn build(&mut self) -> SP1Context<'a>
Build and return the SP1Context.
Clears and resets the builder, allowing it to be reused.
Sourcepub fn hook(
&mut self,
fd: u32,
f: impl FnMut(HookEnv, &[u8]) -> Vec<Vec<u8>> + Send + Sync + 'a,
) -> &mut Self
pub fn hook( &mut self, fd: u32, f: impl FnMut(HookEnv, &[u8]) -> Vec<Vec<u8>> + Send + Sync + 'a, ) -> &mut Self
Add a runtime Hook into the context.
Hooks may be invoked from within SP1 by writing to the specified file descriptor fd
with [sp1_zkvm::io::write], returning a list of arbitrary data that may be read
with successive calls to [sp1_zkvm::io::read].
Panics
Panics if fd <= LOWEST_ALLOWED_FD.
Sourcepub fn without_default_hooks(&mut self) -> &mut Self
pub fn without_default_hooks(&mut self) -> &mut Self
Avoid registering the default hooks in the runtime.
It is not necessary to call this to override hooks — instead, simply
register a hook with the same value of fd by calling Self::hook.
Sourcepub fn calculate_gas(&mut self, value: bool) -> &mut Self
pub fn calculate_gas(&mut self, value: bool) -> &mut Self
Whether gas should be calculated while executing. Defaults to true.
Determines whether the gas field in the ExecutionReport is None or Some.
During proving, gas is not calculated, so this option has no effect.
Disabling gas calculation will likely speed up execution.
Sourcepub fn max_cycles(&mut self, max_cycles: u64) -> &mut Self
pub fn max_cycles(&mut self, max_cycles: u64) -> &mut Self
Set the maximum number of cpu cycles to use for execution.
report.total_instruction_count() will be less than or equal to max_cycles.
Sourcepub fn set_deferred_proof_verification(&mut self, value: bool) -> &mut Self
pub fn set_deferred_proof_verification(&mut self, value: bool) -> &mut Self
Set the deferred proof verification flag.
Sourcepub fn expected_exit_code(&mut self, code: StatusCode) -> &mut Self
pub fn expected_exit_code(&mut self, code: StatusCode) -> &mut Self
Set the expected exit code of the program.
Sourcepub fn proof_nonce(&mut self, nonce: [u32; 4]) -> &mut Self
pub fn proof_nonce(&mut self, nonce: [u32; 4]) -> &mut Self
Set the proof nonce for this execution. This nonce ensures each proof is unique even for identical programs and inputs.