pub struct SP1CoreOpts {
pub minimal_trace_chunk_threshold: u64,
pub shard_size: usize,
pub sharding_threshold: ShardingThreshold,
pub retained_events_presets: HashSet<RetainedEventsPreset>,
pub global_dependencies_opt: bool,
}Expand description
Options for the core prover.
Fields
minimal_trace_chunk_threshold: u64The maximum size of a minimal trace chunk in terms of memory entries.
shard_size: usizeThe size of a shard in terms of cycles. Used for estimating event counts when allocating records.
sharding_threshold: ShardingThresholdThe threshold that determines when to split the shard.
retained_events_presets: HashSet<RetainedEventsPreset>Preset collections of events to retain in a shard instead of deferring.
global_dependencies_opt: boolUse optimized generate_dependencies for global chip.