pub trait ExecutionMode:
Sized
+ Send
+ Sync
+ Clone
+ Copy
+ Default
+ 'static {
const PAGE_PROTECTION_ENABLED: bool;
}Expand description
Execution mode trait for compile-time specialization of page protection behavior.
Required Associated Constants
Sourceconst PAGE_PROTECTION_ENABLED: bool
const PAGE_PROTECTION_ENABLED: bool
Whether page protection checks are enabled for this execution mode.
When false, all page protection code is eliminated at compile time.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".