pub trait Hook {
// Required method
fn invoke_hook(&mut self, env: HookEnv, buf: &[u8]) -> Vec<Vec<u8>>;
}Expand description
A runtime hook. May be called during execution by writing to a specified file descriptor, accepting and returning arbitrary data.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".