IoWriter

Trait IoWriter 

pub trait IoWriter:
    Write
    + Send
    + Sync { }
A trait for Write types to be used in the executor.

This trait is generically implemented for any Write + Send type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<W: Write + Send + Sync> IoWriter for W