pub enum CoreAirId {
Show 36 variants
Cpu = 0,
SyscallCore = 30,
DivRem = 32,
Add = 33,
Addi = 34,
Addw = 35,
Sub = 36,
Subw = 37,
Bitwise = 38,
Mul = 39,
ShiftRight = 40,
ShiftLeft = 41,
Lt = 42,
LoadByte = 43,
LoadHalf = 44,
LoadWord = 45,
LoadX0 = 46,
LoadDouble = 47,
StoreByte = 48,
StoreHalf = 49,
StoreWord = 50,
StoreDouble = 51,
UType = 52,
Branch = 53,
Jal = 54,
Jalr = 55,
SyscallInstrs = 56,
MemoryBump = 57,
StateBump = 58,
MemoryLocal = 61,
Global = 62,
Mprotect = 65,
InstructionDecode = 66,
InstructionFetch = 67,
PageProt = 68,
PageProtLocal = 69,
}Expand description
RV64IM AIR Identifiers.
These identifiers are for the various chips in the rv64im prover. We need them in the executor to compute the memory cost of the current shard of execution.
The CoreAirIds are the AIRs that are not part of precompile shards and not the program or
byte AIR.
Variants
Cpu = 0
The cpu chip, which is a dummy for now, needed for shape loading.
SyscallCore = 30
The syscall core chip.
DivRem = 32
The div rem chip.
Add = 33
The add chip.
Addi = 34
The addi chip.
Addw = 35
The addw chip.
Sub = 36
The sub chip.
Subw = 37
The subw chip.
Bitwise = 38
The bitwise chip.
Mul = 39
The mul chip.
ShiftRight = 40
The shift right chip.
ShiftLeft = 41
The shift left chip.
Lt = 42
The lt chip.
LoadByte = 43
The load byte chip.
LoadHalf = 44
The load half chip.
LoadWord = 45
The load word chip.
LoadX0 = 46
The load x0 chip.
LoadDouble = 47
The load double chip.
StoreByte = 48
The store byte chip.
StoreHalf = 49
The store half chip.
StoreWord = 50
The store word chip.
StoreDouble = 51
The store double chip.
UType = 52
The utype chip.
Branch = 53
The branch chip.
Jal = 54
The jal chip.
Jalr = 55
The jalr chip.
SyscallInstrs = 56
The syscall instructions chip.
MemoryBump = 57
The memory bump chip.
StateBump = 58
The state bump chip.
MemoryLocal = 61
The memory local chip.
Global = 62
The global chip.
Mprotect = 65
The mprotect chip.
InstructionDecode = 66
The instruction decode chip.
InstructionFetch = 67
The instruction fetch chip.
PageProt = 68
The page prot chip.
PageProtLocal = 69
The page prot local chip.