#[repr(u8)]pub enum Opcode {
Show 53 variants
ADD = 0,
ADDI = 1,
SUB = 2,
XOR = 3,
OR = 4,
AND = 5,
SLL = 6,
SRL = 7,
SRA = 8,
SLT = 9,
SLTU = 10,
MUL = 11,
MULH = 12,
MULHU = 13,
MULHSU = 14,
DIV = 15,
DIVU = 16,
REM = 17,
REMU = 18,
LB = 19,
LH = 20,
LW = 21,
LBU = 22,
LHU = 23,
SB = 24,
SH = 25,
SW = 26,
BEQ = 27,
BNE = 28,
BLT = 29,
BGE = 30,
BLTU = 31,
BGEU = 32,
JAL = 33,
JALR = 34,
AUIPC = 35,
LUI = 36,
ECALL = 37,
EBREAK = 38,
ADDW = 39,
SUBW = 40,
SLLW = 41,
SRLW = 42,
SRAW = 43,
LWU = 44,
LD = 45,
SD = 46,
MULW = 47,
DIVW = 48,
DIVUW = 49,
REMW = 50,
REMUW = 51,
UNIMP = 52,
}Expand description
An opcode (short for “operation code”) specifies the operation to be performed by the processor.
In the context of the RISC-V ISA, an opcode specifies which operation (i.e., addition, subtraction, multiplication, etc.) to perform on up to three operands such as registers, immediates, or memory addresses.
While the SP1 zkVM targets the RISC-V ISA, it uses a custom instruction encoding that uses a different set of opcodes. The main difference is that the SP1 zkVM encodes register operations and immediate operations as the same opcode. For example, the RISC-V opcodes ADD and ADDI both become ADD inside the SP1 zkVM. We utilize flags inside the instruction itself to distinguish between the two.
Refer to the “RV32I Reference Card” here for more details.
Variants
ADD = 0
rd ← rs1 + rs2, pc ← pc + 4
ADDI = 1
rd ← rs1 + imm, pc ← pc + 4
SUB = 2
rd ← rs1 - rs2, pc ← pc + 4
XOR = 3
rd ← rs1 ^ rs2, pc ← pc + 4
OR = 4
rd ← rs1 | rs2, pc ← pc + 4
AND = 5
rd ← rs1 & rs2, pc ← pc + 4
SLL = 6
rd ← rs1 << rs2, pc ← pc + 4
SRL = 7
rd ← rs1 >> rs2 (logical), pc ← pc + 4
SRA = 8
rd ← rs1 >> rs2 (arithmetic), pc ← pc + 4
SLT = 9
rd ← (rs1 < rs2) ? 1 : 0 (signed), pc ← pc + 4
SLTU = 10
rd ← (rs1 < rs2) ? 1 : 0 (unsigned), pc ← pc + 4
MUL = 11
rd ← rs1 * rs2 (signed), pc ← pc + 4
MULH = 12
rd ← rs1 * rs2 (half), pc ← pc + 4
MULHU = 13
rd ← rs1 * rs2 (half unsigned), pc ← pc + 4
MULHSU = 14
rd ← rs1 * rs2 (half signed unsigned), pc ← pc + 4
DIV = 15
rd ← rs1 / rs2 (signed), pc ← pc + 4
DIVU = 16
rd ← rs1 / rs2 (unsigned), pc ← pc + 4
REM = 17
rd ← rs1 % rs2 (signed), pc ← pc + 4
REMU = 18
rd ← rs1 % rs2 (unsigned), pc ← pc + 4
LB = 19
rd ← sx(m8(rs1 + imm)), pc ← pc + 4
LH = 20
rd ← sx(m16(rs1 + imm)), pc ← pc + 4
LW = 21
rd ← sx(m32(rs1 + imm)), pc ← pc + 4
LBU = 22
rd ← zx(m8(rs1 + imm)), pc ← pc + 4
LHU = 23
rd ← zx(m16(rs1 + imm)), pc ← pc + 4
SB = 24
m8(rs1 + imm) ← rs2[7:0], pc ← pc + 4
SH = 25
m16(rs1 + imm) ← rs2[15:0], pc ← pc + 4
SW = 26
m32(rs1 + imm) ← rs2[31:0], pc ← pc + 4
BEQ = 27
pc ← pc + ((rs1 == rs2) ? imm : 4)
BNE = 28
pc ← pc + ((rs1 != rs2) ? imm : 4)
BLT = 29
pc ← pc + ((rs1 < rs2) ? imm : 4) (signed)
BGE = 30
pc ← pc + ((rs1 >= rs2) ? imm : 4) (signed)
BLTU = 31
pc ← pc + ((rs1 < rs2) ? imm : 4) (unsigned)
BGEU = 32
pc ← pc + ((rs1 >= rs2) ? imm : 4) (unsigned)
JAL = 33
rd ← pc + 4, pc ← pc + imm
JALR = 34
rd ← pc + 4, pc ← (rs1 + imm) & ∼1
AUIPC = 35
rd ← pc + imm, pc ← pc + 4
LUI = 36
rd ← imm, pc ← pc + 4
ECALL = 37
Transfer control to the ecall handler.
EBREAK = 38
Transfer control to the debugger.
ADDW = 39
rd ← rs1 + rs2, pc ← pc + 4
SUBW = 40
rd ← rs1 - rs2, pc ← pc + 4
SLLW = 41
rd ← rs1 << rs2, pc ← pc + 4
SRLW = 42
rd ← rs1 >> rs2 (logical), pc ← pc + 4
SRAW = 43
rd ← rs1 >> rs2 (arithmetic), pc ← pc + 4
LWU = 44
rd ← sx(m32(rs1 + imm)), pc ← pc + 4
LD = 45
rd ← sx(m8(rs1 + imm)), pc ← pc + 4
SD = 46
m8(rs1 + imm) ← rs2[7:0], pc ← pc + 4
MULW = 47
rd ← rs1 + imm, pc ← pc + 4
DIVW = 48
rd ← rs1 / rs2 (signed), pc ← pc + 4
DIVUW = 49
rd ← rs1 / rs2 (unsigned), pc ← pc + 4
REMW = 50
rd ← rs1 % rs2 (signed), pc ← pc + 4
REMUW = 51
rd ← rs1 % rs2 (unsigned), pc ← pc + 4
UNIMP = 52
Unimplemented instruction.
Implementations
Sourceimpl Opcode
impl Opcode
Sourcepub fn instruction_type(self) -> (InstructionType, Option<InstructionType>)
pub fn instruction_type(self) -> (InstructionType, Option<InstructionType>)
Returns the instruction type for the opcode.