RiscvAirId

Enum RiscvAirId 

pub enum RiscvAirId {
Show 73 variants Cpu = 0, Program = 1, ShaExtend = 2, ShaExtendControl = 3, ShaCompress = 4, ShaCompressControl = 5, EdAddAssign = 6, EdDecompress = 7, Secp256k1Decompress = 8, Secp256k1AddAssign = 9, Secp256k1DoubleAssign = 10, Secp256r1Decompress = 11, Secp256r1AddAssign = 12, Secp256r1DoubleAssign = 13, KeccakPermute = 14, KeccakPermuteControl = 15, Bn254AddAssign = 16, Bn254DoubleAssign = 17, Bls12381AddAssign = 18, Bls12381DoubleAssign = 19, Uint256MulMod = 20, Uint256Ops = 21, U256XU2048Mul = 22, Bls12381FpOpAssign = 23, Bls12381Fp2AddSubAssign = 24, Bls12381Fp2MulAssign = 25, Bn254FpOpAssign = 26, Bn254Fp2AddSubAssign = 27, Bn254Fp2MulAssign = 28, Bls12381Decompress = 29, SyscallCore = 30, SyscallPrecompile = 31, DivRem = 32, Add = 33, Addi = 34, Addw = 35, Sub = 36, Subw = 37, Bitwise = 38, Mul = 39, ShiftRight = 40, ShiftLeft = 41, Lt = 42, LoadByte = 43, LoadHalf = 44, LoadWord = 45, LoadX0 = 46, LoadDouble = 47, StoreByte = 48, StoreHalf = 49, StoreWord = 50, StoreDouble = 51, UType = 52, Branch = 53, Jal = 54, Jalr = 55, SyscallInstrs = 56, MemoryBump = 57, StateBump = 58, MemoryGlobalInit = 59, MemoryGlobalFinalize = 60, MemoryLocal = 61, Global = 62, Byte = 63, Range = 64, Mprotect = 65, InstructionDecode = 66, InstructionFetch = 67, PageProt = 68, PageProtLocal = 69, PageProtGlobalInit = 70, PageProtGlobalFinalize = 71, Poseidon2 = 72,
}
RV64IM AIR Identifiers.

These identifiers are for the various chips in the rv64im prover. We need them in the executor to compute the memory cost of the current shard of execution.

The CoreAirIds are the AIRs that are not part of precompile shards and not the program or byte AIR.

Variants



Cpu = 0

The cpu chip, which is a dummy for now, needed for shape loading.



Program = 1

The program chip.



ShaExtend = 2

The SHA-256 extend chip.



ShaExtendControl = 3

The sha extend control chip.



ShaCompress = 4

The SHA-256 compress chip.



ShaCompressControl = 5

The sha compress control chip.



EdAddAssign = 6

The Edwards add assign chip.



EdDecompress = 7

The Edwards decompress chip.



Secp256k1Decompress = 8

The secp256k1 decompress chip.



Secp256k1AddAssign = 9

The secp256k1 add assign chip.



Secp256k1DoubleAssign = 10

The secp256k1 double assign chip.



Secp256r1Decompress = 11

The secp256r1 decompress chip.



Secp256r1AddAssign = 12

The secp256r1 add assign chip.



Secp256r1DoubleAssign = 13

The secp256r1 double assign chip.



KeccakPermute = 14

The Keccak permute chip.



KeccakPermuteControl = 15

The keccak permute control chip.



Bn254AddAssign = 16

The bn254 add assign chip.



Bn254DoubleAssign = 17

The bn254 double assign chip.



Bls12381AddAssign = 18

The bls12-381 add assign chip.



Bls12381DoubleAssign = 19

The bls12-381 double assign chip.



Uint256MulMod = 20

The uint256 mul mod chip.



Uint256Ops = 21

The uint256 ops chip.



U256XU2048Mul = 22

The u256 xu2048 mul chip.



Bls12381FpOpAssign = 23

The bls12-381 fp op assign chip.



Bls12381Fp2AddSubAssign = 24

The bls12-831 fp2 add sub assign chip.



Bls12381Fp2MulAssign = 25

The bls12-831 fp2 mul assign chip.



Bn254FpOpAssign = 26

The bn254 fp2 add sub assign chip.



Bn254Fp2AddSubAssign = 27

The bn254 fp op assign chip.



Bn254Fp2MulAssign = 28

The bn254 fp2 mul assign chip.



Bls12381Decompress = 29

The bls12-381 decompress chip.



SyscallCore = 30

The syscall core chip.



SyscallPrecompile = 31

The syscall precompile chip.



DivRem = 32

The div rem chip.



Add = 33

The add chip.



Addi = 34

The addi chip.



Addw = 35

The addw chip.



Sub = 36

The sub chip.



Subw = 37

The subw chip.



Bitwise = 38

The bitwise chip.



Mul = 39

The mul chip.



ShiftRight = 40

The shift right chip.



ShiftLeft = 41

The shift left chip.



Lt = 42

The lt chip.



LoadByte = 43

The load byte chip.



LoadHalf = 44

The load half chip.



LoadWord = 45

The load word chip.



LoadX0 = 46

The load x0 chip.



LoadDouble = 47

The load double chip.



StoreByte = 48

The store byte chip.



StoreHalf = 49

The store half chip.



StoreWord = 50

The store word chip.



StoreDouble = 51

The store double chip.



UType = 52

The utype chip.



Branch = 53

The branch chip.



Jal = 54

The jal chip.



Jalr = 55

The jalr chip.



SyscallInstrs = 56

The syscall instructions chip.



MemoryBump = 57

The memory bump chip.



StateBump = 58

The state bump chip.



MemoryGlobalInit = 59

The memory global init chip.



MemoryGlobalFinalize = 60

The memory global finalize chip.



MemoryLocal = 61

The memory local chip.



Global = 62

The global chip.



Byte = 63

The byte chip.



Range = 64

The range chip.



Mprotect = 65

The mprotect chip.



InstructionDecode = 66

The instruction decode chip.



InstructionFetch = 67

The instruction fetch chip.



PageProt = 68

The page prot chip.



PageProtLocal = 69

The page prot local chip.



PageProtGlobalInit = 70

The page prot global init chip.



PageProtGlobalFinalize = 71

The page prot global finalize chip.



Poseidon2 = 72

The poseidon2 chip.

Implementations

Source

impl RiscvAirId

pub fn core() -> Vec<RiscvAirId>

Returns the AIRs that are not part of precompile shards and not the program or byte AIR.

pub fn is_core(self) -> bool

TODO replace these three with subenums or something Whether the ID represents a core AIR.

pub fn is_memory(self) -> bool

Whether the ID represents a memory AIR.

pub fn is_precompile(self) -> bool

Whether the ID represents a precompile AIR.

pub fn rows_per_event(&self) -> usize

The number of rows in the AIR produced by each event.

pub fn control_air_id(self) -> Option<RiscvAirId>

Get the ID of the AIR used in the syscall control implementation.

pub fn as_str(&self) -> &'static str

Returns the string representation of the AIR.