#[repr(u32)]pub enum SyscallCode {
Show 43 variants
HALT = 0,
WRITE = 2,
ENTER_UNCONSTRAINED = 3,
EXIT_UNCONSTRAINED = 4,
SHA_EXTEND = 3_145_989,
SHA_COMPRESS = 65_798,
ED_ADD = 65_799,
ED_DECOMPRESS = 264,
KECCAK_PERMUTE = 65_801,
SECP256K1_ADD = 65_802,
SECP256K1_DOUBLE = 267,
SECP256K1_DECOMPRESS = 268,
BN254_ADD = 65_806,
BN254_DOUBLE = 271,
COMMIT = 16,
COMMIT_DEFERRED_PROOFS = 26,
VERIFY_SP1_PROOF = 27,
BLS12381_DECOMPRESS = 284,
HINT_LEN = 240,
HINT_READ = 241,
UINT256_MUL = 65_821,
U256XU2048_MUL = 65_839,
BLS12381_ADD = 65_822,
BLS12381_DOUBLE = 287,
BLS12381_FP_ADD = 65_824,
BLS12381_FP_SUB = 65_825,
BLS12381_FP_MUL = 65_826,
BLS12381_FP2_ADD = 65_827,
BLS12381_FP2_SUB = 65_828,
BLS12381_FP2_MUL = 65_829,
BN254_FP_ADD = 65_830,
BN254_FP_SUB = 65_831,
BN254_FP_MUL = 65_832,
BN254_FP2_ADD = 65_833,
BN254_FP2_SUB = 65_834,
BN254_FP2_MUL = 65_835,
SECP256R1_ADD = 65_836,
SECP256R1_DOUBLE = 301,
SECP256R1_DECOMPRESS = 302,
UINT256_ADD_CARRY = 65_840,
UINT256_MUL_CARRY = 65_841,
MPROTECT = 306,
POSEIDON2 = 307,
}Expand description
System Calls.
A system call is invoked by the the ecall instruction with a specific value in register t0.
The syscall number is a 32-bit integer with the following little-endian layout:
| Byte 0 | Byte 1 | Byte 2 | Byte 3 |
|---|---|---|---|
| ID | Table | Unused | Unused |
where:
- Byte 0: The system call identifier.
- Byte 1: Whether the handler of the system call has its own table. This is used in the CPU table to determine whether to lookup the syscall using the syscall interaction.
- Byte 2: Previously, this was the number of additional cycles the syscall uses. Now, this byte is unused, as each syscall instruction increments the clock by 256 additionally.
- Byte 3: Currently unused.
Variants
HALT = 0
Halts the program.
WRITE = 2
Write to the output buffer.
ENTER_UNCONSTRAINED = 3
Enter unconstrained block.
EXIT_UNCONSTRAINED = 4
Exit unconstrained block.
SHA_EXTEND = 3_145_989
Executes the SHA_EXTEND precompile.
SHA_COMPRESS = 65_798
Executes the SHA_COMPRESS precompile.
ED_ADD = 65_799
Executes the ED_ADD precompile.
ED_DECOMPRESS = 264
Executes the ED_DECOMPRESS precompile.
KECCAK_PERMUTE = 65_801
Executes the KECCAK_PERMUTE precompile.
SECP256K1_ADD = 65_802
Executes the SECP256K1_ADD precompile.
SECP256K1_DOUBLE = 267
Executes the SECP256K1_DOUBLE precompile.
SECP256K1_DECOMPRESS = 268
Executes the SECP256K1_DECOMPRESS precompile.
BN254_ADD = 65_806
Executes the BN254_ADD precompile.
BN254_DOUBLE = 271
Executes the BN254_DOUBLE precompile.
COMMIT = 16
Executes the COMMIT precompile.
COMMIT_DEFERRED_PROOFS = 26
Executes the COMMIT_DEFERRED_PROOFS precompile.
VERIFY_SP1_PROOF = 27
Executes the VERIFY_SP1_PROOF precompile.
BLS12381_DECOMPRESS = 284
Executes the BLS12381_DECOMPRESS precompile.
HINT_LEN = 240
Executes the HINT_LEN precompile.
HINT_READ = 241
Executes the HINT_READ precompile.
UINT256_MUL = 65_821
Executes the UINT256_MUL precompile.
U256XU2048_MUL = 65_839
Executes the U256XU2048_MUL precompile.
BLS12381_ADD = 65_822
Executes the BLS12381_ADD precompile.
BLS12381_DOUBLE = 287
Executes the BLS12381_DOUBLE precompile.
BLS12381_FP_ADD = 65_824
Executes the BLS12381_FP_ADD precompile.
BLS12381_FP_SUB = 65_825
Executes the BLS12381_FP_SUB precompile.
BLS12381_FP_MUL = 65_826
Executes the BLS12381_FP_MUL precompile.
BLS12381_FP2_ADD = 65_827
Executes the BLS12381_FP2_ADD precompile.
BLS12381_FP2_SUB = 65_828
Executes the BLS12381_FP2_SUB precompile.
BLS12381_FP2_MUL = 65_829
Executes the BLS12381_FP2_MUL precompile.
BN254_FP_ADD = 65_830
Executes the BN254_FP_ADD precompile.
BN254_FP_SUB = 65_831
Executes the BN254_FP_SUB precompile.
BN254_FP_MUL = 65_832
Executes the BN254_FP_MUL precompile.
BN254_FP2_ADD = 65_833
Executes the BN254_FP2_ADD precompile.
BN254_FP2_SUB = 65_834
Executes the BN254_FP2_SUB precompile.
BN254_FP2_MUL = 65_835
Executes the BN254_FP2_MUL precompile.
SECP256R1_ADD = 65_836
Executes the SECP256R1_ADD precompile.
SECP256R1_DOUBLE = 301
Executes the SECP256R1_DOUBLE precompile.
SECP256R1_DECOMPRESS = 302
Executes the SECP256R1_DECOMPRESS precompile.
UINT256_ADD_CARRY = 65_840
Executes the UINT256_ADD_CARRY precompile.
UINT256_MUL_CARRY = 65_841
Executes the UINT256_MUL_CARRY precompile.
MPROTECT = 306
Executes the MPROTECT syscall.
POSEIDON2 = 307
Executes the POSEIDON2 syscall.
Implementations
Sourceimpl SyscallCode
impl SyscallCode
Sourcepub fn from_u32(value: u32) -> Self
pub fn from_u32(value: u32) -> Self
Create a SyscallCode from a u32.
Sourcepub fn syscall_id(self) -> u32
pub fn syscall_id(self) -> u32
Get the system call identifier.
Sourcepub fn should_send(self) -> u32
pub fn should_send(self) -> u32
Get whether the handler of the system call has its own table.
Sourcepub fn count_map(&self) -> Self
pub fn count_map(&self) -> Self
Map a syscall to another one in order to coalesce their counts.
Sourcepub fn fp_op_map(&self) -> FieldOperation
pub fn fp_op_map(&self) -> FieldOperation
Map a syscall to a field operation.
Sourcepub fn uint256_op_map(&self) -> Uint256Operation
pub fn uint256_op_map(&self) -> Uint256Operation
Map a syscall to a uint256 operation.
Sourcepub fn as_air_id(self) -> Option<RiscvAirId>
pub fn as_air_id(self) -> Option<RiscvAirId>
Get the ID of the AIR used in the syscall implementation.
Sourcepub fn touched_addresses(&self) -> usize
pub fn touched_addresses(&self) -> usize
The maximum number of touched words for each syscall code.
Sourcepub fn touched_pages(&self) -> usize
pub fn touched_pages(&self) -> usize
The maximum number of touched pages for each syscall code.