PrecompileLocalMemory

Trait PrecompileLocalMemory 

pub trait PrecompileLocalMemory {
    // Required methods
    fn get_local_mem_events(
        &self,
    ) -> impl IntoIterator<Item = &MemoryLocalEvent>;
    fn get_local_page_prot_events(
        &self,
    ) -> impl IntoIterator<Item = &PageProtLocalEvent>;
}
Trait to retrieve all the local memory events from a vec of precompile events.

Required Methods

fn get_local_mem_events(&self) -> impl IntoIterator<Item = &MemoryLocalEvent>

Get an iterator of all the local memory events.

fn get_local_page_prot_events( &self, ) -> impl IntoIterator<Item = &PageProtLocalEvent>

Get an iterator of all the local page prot events.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl PrecompileLocalMemory for Vec<(SyscallEvent, PrecompileEvent)>

Implementors