pub struct MinimalExecutor { /* private fields */ }Expand description
A minimal trace executor.
Implementations
Sourceimpl MinimalExecutor
impl MinimalExecutor
Sourcepub fn simple(program: Arc<Program>) -> Self
pub fn simple(program: Arc<Program>) -> Self
Create a new minimal executor with no tracing or debugging.
Sourcepub fn with_input(&mut self, input: &[u8])
pub fn with_input(&mut self, input: &[u8])
Add input to the executor.
Sourcepub fn execute_chunk(&mut self) -> Option<TraceChunkRaw>
pub fn execute_chunk(&mut self) -> Option<TraceChunkRaw>
Execute the program. Returning a trace chunk if the program has not completed.
Sourcepub fn get_memory_value(&self, addr: u64) -> MemValue
pub fn get_memory_value(&self, addr: u64) -> MemValue
Get the current value at an address.
Sourcepub fn clk(&self) -> u64
pub fn clk(&self) -> u64
Get the current clock of the JIT function.
This clock is incremented by 8 or 256 depending on the instruction.
Sourcepub fn global_clk(&self) -> u64
pub fn global_clk(&self) -> u64
Get the global clock of the JIT function.
This clock is incremented by 1 per instruction.
Sourcepub fn public_values_stream(&self) -> &Vec<u8> ⓘ
pub fn public_values_stream(&self) -> &Vec<u8> ⓘ
Get the public values stream of the JIT function.
Sourcepub fn into_public_values_stream(self) -> Vec<u8> ⓘ
pub fn into_public_values_stream(self) -> Vec<u8> ⓘ
Consume self, and return the public values stream.
Sourcepub fn memory(&self) -> MemoryView<'_>
pub fn memory(&self) -> MemoryView<'_>
Get a view of the current memory of the JIT function.
Sourcepub fn unsafe_memory(&self) -> UnsafeMemory
pub fn unsafe_memory(&self) -> UnsafeMemory
Get an unsafe memory view of the JIT function.
This allows reading without lifetime and mutability constraints.
Sourceimpl MinimalExecutor
impl MinimalExecutor
Sourcepub fn emit_globals(
&self,
record: &mut ExecutionRecord,
final_registers: [MemoryRecord; 32],
touched_addresses: HashSet<u64>,
)
pub fn emit_globals( &self, record: &mut ExecutionRecord, final_registers: [MemoryRecord; 32], touched_addresses: HashSet<u64>, )
Postprocess into an existing ExecutionRecord,
consisting of all the MemoryInitializeFinalizeEvents.
Sourcepub fn get_hint_event_addrs(&self) -> HashSet<u64>
pub fn get_hint_event_addrs(&self) -> HashSet<u64>
Get set of addresses that were hinted.