pub struct SP1Context<'a> {
pub hook_registry: Option<HookRegistry<'a>>,
pub max_cycles: Option<u64>,
pub deferred_proof_verification: bool,
pub expected_exit_code: StatusCode,
pub calculate_gas: bool,
pub proof_nonce: [u32; 4],
pub io_options: IoOptions<'a>,
}Expand description
Context to run a program inside SP1.
Fields
hook_registry: Option<HookRegistry<'a>>The registry of hooks invocable from inside SP1.
Note: None denotes the default list of hooks.
max_cycles: Option<u64>The maximum number of cpu cycles to use for execution.
deferred_proof_verification: boolDeferred proof verification.
expected_exit_code: StatusCodeThe expected exit code of the program.
calculate_gas: boolWhether gas (available in the ExecutionReport) should be calculated during execution.
Does nothing while proving.
This option will noticeably slow down execution, so it should be disabled in most cases.
proof_nonce: [u32; 4]The nonce used for this specific proof execution (4 x u32 = 128 bits of entropy). This nonce ensures each proof is unique even for identical programs and inputs.
io_options: IoOptions<'a>The IO options for the [SP1Executor].
Implementations
Sourceimpl<'a> SP1Context<'a>
impl<'a> SP1Context<'a>
Sourcepub fn builder() -> SP1ContextBuilder<'a>
pub fn builder() -> SP1ContextBuilder<'a>
Create a new context builder. See SP1ContextBuilder for more details.